package com.iona.fuse.demo.logisticx.model;

/**
 * 
 * Copyright  2007-2008 IONA Technologies PLC.
 *           All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 **/

import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

import javax.persistence.*;
import javax.xml.bind.annotation.XmlRootElement;

import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.commons.lang.builder.ToStringStyle;

/**
 * Represents an order from a customer. 
 * 
 * @author bsnyder
 *
 */

@Entity(name = "Ord")
@XmlRootElement(name = "Order")
public class Order 
{
    @Id
    @GeneratedValue
    @Column(name="ORDER_ID")
    private Long orderId;

    private Calendar orderDate;

    @OneToOne(cascade=CascadeType.ALL)
    @JoinColumn(name="LINEITEM_ID")
    private LineItem lineItem;

    private long customerId; 

    @OneToOne(cascade=CascadeType.ALL)
    private OrderStatus orderStatus;

    private String customerPoNumber;
    
    public Order() {

    }
   
    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }

    public Calendar getOrderDate() {
        return orderDate;
    }

    public void setOrderDate(Calendar orderDate) {
        this.orderDate = orderDate;
    }


    public LineItem getLineItem() {
        return lineItem;
    }

    public void setLineItem(LineItem lineItem) {
        this.lineItem = lineItem;
    }
    
    public long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(long customerId) {
        this.customerId = customerId;
    }

    public OrderStatus getStatus() {
        return orderStatus;
    }

    public void setStatus(OrderStatus status) {
        this.orderStatus = status;
    }

    public String getCustomerPoNumber() {
        return customerPoNumber;
    }

    public void setCustomerPoNumber(String customerPoNumber) {
        this.customerPoNumber = customerPoNumber;
    }
    
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    /**
     * Used when constructing a jms order status text message. Doesn't
     * include all information, just because this is all we want for now.
     */
    public String toXml() {
        String xml = "<order>" 
            + "<customerPoNumber>" + customerPoNumber + "</customerPoNumber>"
            + "<orderId>" + orderId + "</orderId>"
            + "</order>";
        return xml;
    }
}
