package com.iona.fuse.demo.logisticx.model.factory;

/**
 * 
 * Copyright  2007-2008 IONA Technologies PLC.
 *           All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 **/

import org.springframework.beans.InvalidPropertyException;
import org.springframework.beans.factory.FactoryBean;
import org.springframework.beans.factory.InitializingBean;
import com.iona.fuse.demo.logisticx.model.Order;

/**
 * A simple {@link org.springframework.beans.factory.FactoryBean} to make 
 * creating a {@link com.iona.fuse.demo.logisticx.model.Order} object easier. 
 * 
 * @author bsnyder
 * @since 1.0
 */
public class OrderFactoryBean implements FactoryBean, InitializingBean {
    
    private Order defaultOrder = new Order();
    
    private long customerId = 0;

    /**
     * Creates a minimal {@link com.iona.fuse.demo.logisticx.model.Order} object.
     * This method will be fleshed out further over time. 
     */
    public Object getObject() throws Exception {
        defaultOrder.setCustomerId(getCustomerId());
        
        return defaultOrder;
    }

    public Class getObjectType() {
        return Order.class;
    }

    public boolean isSingleton() {
        return false;
    }
    
    public void afterPropertiesSet() throws Exception {
        validateConfiguration();        
    }
    
    protected void validateConfiguration() {
        if (new Long(getCustomerId()).equals(new Long(0)) ) {
            String customerIdErrorMsg = "The 'customerId' property is required to be populated. " + 
            "Make sure to set the 'customerId' property in your Spring beans XML."; 
            
            throw new InvalidPropertyException(Order.class, "customerId", customerIdErrorMsg);
        }
    }

    public long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(long customerId) {
        this.customerId = customerId;
    }

}
