package com.iona.fuse.demo.logisticx.model.jpa;

/**
 * 
 * Copyright  2007-2008 IONA Technologies PLC.
 *           All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 **/

import java.util.ArrayList;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;
import javax.persistence.Query;

import com.iona.fuse.demo.logisticx.model.LineItem;
import com.iona.fuse.demo.logisticx.model.Order;
import com.iona.fuse.demo.logisticx.model.factory.OrderFactoryBean;
import junit.framework.TestCase;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.junit.AfterClass;
import org.junit.BeforeClass;
import org.junit.Test;

public class JpaTest extends TestCase {
    private static final transient Log log = LogFactory.getLog(JpaTest.class);
    private EntityManagerFactory emFactory;
    private EntityManager em;

    @BeforeClass
    protected void setUp() throws Exception {
        super.setUp();
        emFactory = Persistence.createEntityManagerFactory("order-test-processor");
        em = emFactory.createEntityManager();
    }

    @AfterClass
    protected void tearDown() throws Exception {

        if (em != null) {
            em.close();
        }
        if (emFactory != null) {
            emFactory.close();
        }

        super.tearDown();
    }

    @Test
    public void testOrderPersistence() throws Exception {
        try {
            em.getTransaction().begin();

            // Create an order with lineitems
            OrderFactoryBean ofb = new OrderFactoryBean();
            Order order = (Order) ofb.getObject();
            order.setCustomerId(234234);
            order.setCustomerPoNumber("PO#1234");

            LineItem item = new LineItem();
            item.setName("Line Item 1");
            order.setLineItem(item);

            // Save the order
            em.persist(order);
            em.getTransaction().commit();

            // Retrieve the order
            Query query = em.createQuery("select o from Ord o where o.orderId = " + order.getOrderId());
            List<Order> list = query.getResultList();

            assertEquals("There should only be one order with the ID: " + order.getOrderId(), list.size(), 1);
            
        } catch (Exception ex) {
            if (em.getTransaction().isActive()){
                em.getTransaction().rollback();
            }
            ex.printStackTrace();
            fail("Exception during testOrderPersistence");
        }
    }
}
